@@ -185,7 +185,7 @@ ArrangeSingleAuthor <- function(y){
     if (!inherits(tmp, 'try-error'))
       y <- deparseLatex(latexToUtf8(tmp))
   }
-  parts <- unlist(strsplit(y, ','))
+  parts <- unlist(strsplit(y, ", ?(?![^{}]*})", perl = TRUE))  # split on commas not in braces
   len.parts <- length(parts)
   if (len.parts == 1L){
     #     parts <- "{Barnes} {and} {Noble,} {Inc.}"
@@ -251,7 +251,7 @@ ArrangeSingleAuthor <- function(y){
              c(cleanupLatex(von), cleanupLatex(sub(vonrx, '', parts[1L])), cleanupLatex(parts[2L])))
     }
   }else{
-    stop('Invalid name format in bibentry.')
+    stop('Invalid format.')
   }
 }
 
@@ -306,7 +306,7 @@ MakeCitationList <- function( x, header, footer){
 
 #' @keywords internal
 .is_not_nonempty_text <- function(x){
-  is.null(x) || any(is.na(x)) || all(grepl("^[[:space:]]*$", x))
+  is.null(x) || any(is.na(x)) || all(grepl("^[[:space:]]*$", x, useBytes = TRUE))
 }
 
 #' @keywords internal
@@ -387,9 +387,94 @@ MakeCitationList <- function( x, header, footer){
   else unlist(lapply(s, paste, collapse = "\n"), use.names = FALSE)
 }
 
+.format_BibEntry_as_yaml <- function(x, collapse = FALSE){
+  if (!length(x))
+    return("bibentry()")
+  x$.index <- NULL
+  x$dateobj <- NULL
+  anames <- bibentry_attribute_names
+  manames <- c("mheader", "mfooter")
+  .clean <- MakeBibLaTeX()$cleanupLatex
+  .collapse <- MakeBibLaTeX()$collapse
+  .blanks <- function(n) paste(rep.int(" ", n), collapse = "")
+  .format_call_RR <- function(cname, cargs){
+    cargs <- as.list(cargs)
+    # cargs <- lapply(cargs, function(x) collapse(clean(x)))
+    n <- length(cargs)
+    lens <- sapply(cargs, length)
+    sums <- cumsum(lens)
+    starters <- c(sprintf("%s", cname), rep.int(.blanks(nchar(cname) +
+                                                           1L), sums[n] - 1L))
+    # trailers <- c(rep.int("", sums[n] - 1L), ")")
+    trailers <- c(rep.int("", sums[n] - 1L), "")
+    # trailers[sums[-n]] <- ","
+    sprintf("%s%s%s", starters, unlist(cargs), trailers)
+  }
+  .format_person_as_yaml <- function(x){
+    s <- lapply(unclass(x), function(e){
+      e <- e[!sapply(e, is.null)]
+      cargs <- sprintf("%s: %s", names(e), sapply(e, deparse))
+      .format_call_RR("\n    - ", cargs)
+    })
+    ## if (length(s))
+    ##   s <- paste0("\n", s, collapse = "")
+    ## if (length(s) > 1L)
+    ##  .format_call_RR("\n", s)
+    ## else unlist(s, use.names = FALSE)
+    ## c("\n", unlist(s, use.names = FALSE))
+    ## browser()
+    unlist(s, use.names = FALSE)
+  }
+  f <- function(e){
+    if (inherits(e, "person"))
+      .format_person_as_yaml(e)
+    else deparse(e)
+  }
+  g <- function(u, v){
+    if (u == "bibtype")
+      u <- "type"
+    if (u == "key")
+      u <- "id"
+    prefix <- sprintf("%s: ", u)
+    v <- .collapse(.clean(v))
+
+    n <- length(v)
+    if (n > 1L)
+      prefix <- c(prefix, rep.int(.blanks(nchar(prefix)),
+                                  n - 1L))
+    sprintf("%s%s", prefix, v)
+  }
+  s <- lapply(unclass(x), function(e){
+    a <- Filter(length, attributes(e)[anames])
+    e <- e[!sapply(e, is.null)]
+    ind <- !is.na(match(names(e), c(anames, manames, "other")))
+    if (any(ind)) {
+      other <- paste(names(e[ind]), sapply(e[ind], f),
+                     sep = " = ")
+      other <- Map(g, names(e[ind]), sapply(e[ind], f))
+      other <- .format_call_RR("list", other)
+      e <- e[!ind]
+    }
+    else {
+      other <- NULL
+    }
+    c(Map(g, names(a), sapply(a, deparse)), Map(g, names(e),
+                                                sapply(e, f)), if (length(other)) list(g("other",
+                                                                                         other)))
+  })
+  if (!is.null(mheader <- attr(x, "mheader")))
+    s[[1L]] <- c(s[[1L]], paste("mheader = ", deparse(mheader)))
+  if (!is.null(mfooter <- attr(x, "mfooter")))
+    s[[1L]] <- c(s[[1L]], paste("mfooter = ", deparse(mfooter)))
+  s <- Map(.format_call_RR, "- ", s)
+  if (collapse && (length(s) > 1L))
+    paste(.format_call_RR("", s), collapse = "\n")
+  else unlist(lapply(s, paste, collapse = "\n"), use.names = FALSE)
+}
+
 bibentry_attribute_names <- c("bibtype", "textVersion", "header", "footer", "key", "dateobj")
 bibentry_format_styles <- c("text", "Bibtex", "citation", "html", "latex", "textVersion",
-                            "R", "Biblatex", "markdown")
+                            "R", "Biblatex", "markdown", "yaml")
 
 # from utils:::toBibtex, good for matching by given name initials only
 #' @keywords internal
@@ -418,70 +503,70 @@ bibentry_list_attribute_names <- c("mheader", "mfooter", "strings")
   unlist(keys)
 }
 
-#' @keywords internal
-#' @importFrom XML xmlValue
-#' @importFrom stringr str_sub str_trim
-ParseGSCites <- function(l, encoding, check.entries=.BibOptions$check.entries){
-  if (!length(l))
-    return(list())
-  td <- l[[1L]]
+## @keywords internal
+## @importFrom XML xmlValue
+## @importFrom stringr str_sub str_trim
+## ParseGSCites <- function(l, encoding, check.entries=.BibOptions$check.entries){
+##   if (!length(l))
+##     return(list())
+##   td <- l[[1L]]
 
-  title <- xmlValue(td[[1L]], encoding)
-  author <- xmlValue(td[[3L]], encoding)
-  cited_by <- as.numeric(xmlValue(l[[2L]][[1L]], encoding))
-  if (is.na(cited_by))  # no citation yet
-    cited_by <- "0"
-  year <- as.numeric(xmlValue(l[[4L]], encoding))
-  src <- xmlValue(td[[5L]])
-  first_digit <- as.numeric(regexpr("[\\[\\(]?\\d",
-                                    src)) - 1L
-  ids <- which(first_digit < 0L)
-  first_digit <- replace(first_digit, ids, str_length(src)[ids])
-  journal <- str_trim(str_sub(src, 1L, first_digit))
-  trailing_commas <- as.numeric(regexpr(",$", journal)) - 1L
-  ids <- which(trailing_commas < 0L)
-  trailing_commas <- replace(trailing_commas, ids,
-                             str_length(journal)[ids])
-  journal <- str_sub(journal, 1L, trailing_commas)
-  numbers <- str_trim(str_sub(src, first_digit + 1L,
-                              str_length(src)))
+##   title <- xmlValue(td[[1L]], encoding)
+##   author <- xmlValue(td[[3L]], encoding)
+##   cited_by <- as.numeric(xmlValue(l[[2L]][[1L]], encoding))
+##   if (is.na(cited_by))  # no citation yet
+##     cited_by <- "0"
+##   year <- as.numeric(xmlValue(l[[4L]], encoding))
+##   src <- xmlValue(td[[5L]])
+##   first_digit <- as.numeric(regexpr("[\\[\\(]?\\d",
+##                                     src)) - 1L
+##   ids <- which(first_digit < 0L)
+##   first_digit <- replace(first_digit, ids, str_length(src)[ids])
+##   journal <- str_trim(str_sub(src, 1L, first_digit))
+##   trailing_commas <- as.numeric(regexpr(",$", journal)) - 1L
+##   ids <- which(trailing_commas < 0L)
+##   trailing_commas <- replace(trailing_commas, ids,
+##                              str_length(journal)[ids])
+##   journal <- str_sub(journal, 1L, trailing_commas)
+##   numbers <- str_trim(str_sub(src, first_digit + 1L,
+##                               str_length(src)))
 
-  # handle '...' in title, journal, or authors
-  if (!identical(check.entries, FALSE)){
-    if (is.null(title <- CheckGSDots(title, title, check.entries)) ||
-          is.null(author <- CheckGSDots(author, title, check.entries)) ||
-          is.null(journal <- CheckGSDots(journal, title, check.entries)))
-      return(NA)
-  }
+##   # handle '...' in title, journal, or authors
+##   if (!identical(check.entries, FALSE)){
+##     if (is.null(title <- CheckGSDots(title, title, check.entries)) ||
+##           is.null(author <- CheckGSDots(author, title, check.entries)) ||
+##           is.null(journal <- CheckGSDots(journal, title, check.entries)))
+##       return(NA)
+##   }
 
-  res <- list(title = title, author = author,
-              journal = journal, number = numbers, cites = cited_by,
-              year = year)
-  if (is.na(res$number) || res$number==''){  # assume book entry if no number
-    if (as.numeric(cited_by) < 10L){
-      attr(res, 'entry') <- "report"
-      res$institution <- res$journal
-      res$type <- "techreport"
-    }else{
-      attr(res, 'entry') <- "book"
-      res$publisher <- res$journal
-    }
-    res$number <- NULL
-    res$journal <- NULL
-  }else{
-    attr(res, 'entry') <- 'article'
-    numbers <- ProcessGSNumbers(res$number)
-    res$number <- numbers$number
-    res$pages <- numbers$pages
-    res$volume <- numbers$volume
-  }
+##   res <- list(title = title, author = author,
+##               journal = journal, number = numbers, cites = cited_by,
+##               year = year)
+##   if (is.na(res$number) || res$number==''){  # assume book entry if no number
+##     if (as.numeric(cited_by) < 10L){
+##       attr(res, 'entry') <- "report"
+##       res$institution <- res$journal
+##       res$type <- "techreport"
+##     }else{
+##       attr(res, 'entry') <- "book"
+##       res$publisher <- res$journal
+##     }
+##     res$number <- NULL
+##     res$journal <- NULL
+##   }else{
+##     attr(res, 'entry') <- 'article'
+##     numbers <- ProcessGSNumbers(res$number)
+##     res$number <- numbers$number
+##     res$pages <- numbers$pages
+##     res$volume <- numbers$volume
+##   }
 
-  res$author <- ProcessGSAuthors(res$author)  # format authors for MakeBibEntry
-  # create key
-  attr(res, "key") <- CreateBibKey(res$title, res$author, res$year)
+##   res$author <- ProcessGSAuthors(res$author)  # format authors for MakeBibEntry
+##   # create key
+##   attr(res, "key") <- CreateBibKey(res$title, res$author, res$year)
 
-  return(res)
-}
+##   return(res)
+## }
 
 
 #' @keywords internal
@@ -646,8 +731,21 @@ MakeBibEntry <- function(x, to.person = TRUE){
   y <- as.list(x)
   names(y) <- tolower(names(y))
   fun <- ifelse(to.person, "ArrangeAuthors", "as.person")
-  lapply(intersect(names(y), .BibEntryNameList), function(fld)
-         y[[fld]] <<- do.call(fun, list(y[[fld]])))
+  name.fields <- intersect(names(y), .BibEntryNameList)
+  line.no <- if (is.null(attr(x, "srcref")))
+               ""
+             else
+               paste0("(line", attr(x, "srcref")[1], ") ")
+  lapply(name.fields, function(fld)
+         y[[fld]] <<- tryCatch(do.call(fun, list(y[[fld]])),
+                        error = function(e){
+                        message(sprintf("Ignoring entry '%s' %sbecause: \n\tThe name list field '%s' cannot be parsed\n",
+                                          attr(x, "key"), line.no, fld))
+                            NA
+                            }))
+  # Check if any were invalid, if so don't add entry
+  if (any(is.na(y)))
+       return(NULL)
   ## if (to.person){
   ##   lapply(intersect(names(y), .BibEntryNameList), function(fld){
   ##                if (fld %in% names(y))
@@ -664,19 +762,14 @@ MakeBibEntry <- function(x, to.person = TRUE){
   if (type != 'set')
     tdate <- ProcessDates(y)
 
-  res <- try(BibEntry(bibtype = type, key = key, dateobj = tdate, other = y), TRUE)
-  if (inherits(res, 'try-error')){
-    if(!is.null(y[['title']])){
-      message(paste0('Ignoring entry titled \"', y[['title']], '\" because ', strsplit(res, '\\n[[:space:]]*')[[1]][2]))
-      #message(strsplit(res, '\n'), '\n')  # relies on bibentry errors being two lines
-    }else{
-      message(paste0('Ignoring entry with key \"', key, '\" because ', strsplit(res, '\\n[[:space:]]*')[[1]][2]))
-      # message(strsplit(res, '\n'), '\n')  # relies on bibentry errors being two lines
-    }
-    return(NULL)
-  }
-
-  return(res)
+  tryCatch(BibEntry(bibtype = type, key = key, dateobj = tdate, other = y),
+            error = function(e){
+                message(sprintf("Ignoring entry '%s' %sbecause:\n\t%s\n",
+                         key,
+                         line.no,
+                         conditionMessage(e)))
+                NULL
+                })
 }
 
 #' @keywords internal
