@@ -516,7 +516,7 @@ fmtDOI <- switch(docstyle, html = function(doi){
   }
 }, markdown = function(doi){
   if (length(doi)){
-    paste0("DOI: [href=http://dx.doi.org/", doi, "](", doi, ").")
+    paste0("DOI: [", doi, "](http://dx.doi.org/", doi, ").")
   }
 }, label(prefix = 'DOI: ', suffix = '.'))
 
@@ -1142,4 +1142,4 @@ formatUnpublished <- function(paper){
 }
 
 environment()
-})
\ No newline at end of file
+})
