@@ -77,7 +77,7 @@
     }
     remain.dup.f <- setdiff(fields.to.check, c('bibtype', 'key'))
     if (length(remain.dup.f)){
-      dup.ind <- which(sapply(unclass(e2[possible.dup]),
+      dup.ind <- sapply(unclass(e2[possible.dup]),
                       function(x, y, flds){
                         x <- x[flds]
                         for (i in seq_along(y)){
@@ -85,7 +85,9 @@
                             return(TRUE)
                         }
                         return(FALSE)
-                      }, y = unclass(e1), flds = remain.dup.f))
+                    }, y = unclass(e1), flds = remain.dup.f)
+      if (length(dup.ind))
+          dup.ind <- which(dup.ind)
     }else{
       dup.ind <- possible.dup
     }
