@@ -31,29 +31,30 @@
 #'   ReadCrossRef(query = 'carroll journal of the american statistical association',
 #'     year = 2012, limit = 2)
 #' }
-ReadCrossRef <- function(query, limit = 5, sort = 'relevance', year = NULL,
-                         min.relevance = 80, temp.file = tempfile(fileext = '.bib'),
+ReadCrossRef <- function(query, limit = 5, sort = "relevance", year = NULL,
+                         min.relevance = 80, temp.file = tempfile(fileext = ".bib"),
                          delete.file = TRUE, verbose = FALSE){
-  if (is.na(query))
-    return(NA)
-  good <- 0
+  if (.is_not_nonempty_text(query))
+    stop(gettextf("specify a valid %s", sQuote("query")))
+  bad <- 0
 
   ## file.create(temp.file)
-  # if query is valid doi, skip search and get BibTeX entry right away
+  ## if query is valid doi, skip search and get BibTeX entry right away
   if (!is.na(.doi <- SearchDOIText(query))){
-
-    good <- GetCrossRefBibTeX(paste0('http://dx.doi.org/', .doi), temp.file)
+    num.res <- 1
+    bad <- GetCrossRefBibTeX(paste0("http://dx.doi.org/", .doi), temp.file)
   }else{
     results <- try(getForm("http://search.crossref.org/dois", q=query, year=year,
                            sort=sort, rows=limit))
-    if (inherits(results, 'try-error'))
-      return(NA)
+    if (inherits(results, "try-error"))
+      stop(gettextf("RCurl failed to GET results from CrossRef: %s", geterrmessage()))
+
 
     fromj <- RJSONIO::fromJSON(results)
     num.res <- min(limit, length(fromj))
     if(num.res == 0L){
-      message(paste0('Query \"', query, '\" returned no matches'))
-      return(NA)
+      message(gettextf("query %s returned no matches", dQuote(query)))
+      return()
     }
 
     if (num.res > 0L){
@@ -64,22 +65,24 @@ ReadCrossRef <- function(query, limit = 5, sort = 'relevance', year = NULL,
      # entries <- vector('character', num.res)
       relevancies <- numeric(num.res)
       for(i in 1:num.res){
-        if(verbose){
-          message(paste0('Including Entry: ', fromj[[i]]$fullCitation))
-          message(paste0('Relevancy score: ', fromj[[i]]$normalizedScore))
-        }
-        if(fromj[[i]]$normalizedScore >= min.relevance){
-          good <- good + GetCrossRefBibTeX(fromj[[i]]$doi, temp.file)
-        }
+        if (verbose)
+            message(gettextf("including the following entry with relevancy score %s:\n%s",
+                             fromj[[i]]$fullCitation, fromj[[i]]$normalizedScore))
+        if (fromj[[i]]$normalizedScore >= min.relevance)
+          bad <- bad + GetCrossRefBibTeX(fromj[[i]]$doi, temp.file)
       }
     }
   }  # end else for not DOI query case
-  if (good == 0L){
-    message('No results')
+  if (bad == num.res){
+    message(gettextf("no results with relavency score greater than %s successfully retrieved",
+                       sQuote("min.relevance")))
     return()
   }
 
   bib.res <- try(ReadBib(file=temp.file, .Encoding='UTF-8'), TRUE)
+  if (inherits(bib.res, "try-error"))
+      stop(gettextf("failed to parse the returned BibTeX results; if %s %s%s", sQuote(delete.file),
+                     "is FALSE, you can try viewing and editing the file: ", temp.file))
 
   return(bib.res)
 }
@@ -88,16 +91,16 @@ ReadCrossRef <- function(query, limit = 5, sort = 'relevance', year = NULL,
 GetCrossRefBibTeX <- function(doi, tmp.file){
   temp <- try(getURLContent(url=doi,
                .opts = curlOptions(httpheader = c(Accept = "application/x-bibtex"),
-                     followLocation=TRUE)))
+                     followLocation=TRUE)), TRUE)
   if(is.raw(temp))
     temp <- rawToChar(temp)
-  if (inherits(temp, 'try-error') || temp[1] == "<h1>Internal Server Error</h1>" ||
+  if (inherits(temp, "try-error") || temp[1] == "<h1>Internal Server Error</h1>" ||
       !grepl("^@", temp)){  # last one for occasional non-bibtex returned by CrossRef
-    message(paste0('Server error for doi ', doi, ', you may want to try again.'))
-    return(0L)
+    message(gettextf("server error for doi %s, you may want to try again.", dQuote(doi)))
+    return(1L)
   }
-  temp <- gsub('&amp;', '&', temp)
+  temp <- gsub("&amp;", "&", temp)
   temp <- sub("^@[Dd]ata", "@online", temp)  # Crossref uses data type for some entries
   write(temp, file = tmp.file, append=TRUE)
-  return(1L)
+  return(0L)
 }
